<?php

namespace Drupal\video_embed_avideo\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Admin-Form for Video Embed AVideo Module.
 *
 * @package Drupal\video_embed_avideo\Form
 */
class AdminSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'video_embed_avideo_admin_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'video_embed_avideo.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('video_embed_avideo.settings');

    $form['avideo'] = [
      '#tree' => TRUE,
      '#type' => 'fieldset',
      '#title' => $this->t('AVideo settings for Video Embed Field'),
    ];

    $form['avideo']['hostname'] = [
      '#type' => 'url',
      '#placeholder' => 'https://www.your-avideo-host.com',
      '#size' => 60,
      '#maxlength' => 128,
      '#title' => $this->t('URL of your AVideo host'),
      '#default_value' => $config->get('avideo.hostname'),
      '#description' => $this->t('The URL is used to identify the associated videos. For example, if you enter <em>https://www.your-avideo-host.com</em> then you can use <em>https://www.your-avideo-host.com/v/8</em> or <em>https://www.your-avideo-host.com/video/8</em> or <em>https://www.your-avideo-host.com/videoEmbed/8</em> as Video-URL.'),
    ];

    $form['avideo']['portalname'] = [
      '#type' => 'textfield',
      '#placeholder' => 'My awesome self-hosted Video Portal',
      '#size' => 60,
      '#maxlength' => 128,
      '#title' => $this->t('Human readable name of your AVideo portal'),
      '#default_value' => $config->get('avideo.portalname'),
      '#description' => $this->t('The name is used to label the iframe correctly (accessability).'),
    ];

    $form['avideo']['iframe'] = [
      '#type' => 'radios',
      '#options' => [
        'embed' => $this->t('Embed-Video (e.g. /videoEmbed/8)'),
        'full' => $this->t('Full page (e.g. /v/8)'),
      ],
      '#title' => $this->t('Source for iframe'),
      '#default_value' => $config->get('avideo.iframe'),
      '#description' => $this->t('Type for iframe source.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('video_embed_avideo.settings');
    $config->set('avideo', $form_state->getValue('avideo'));
    $config->save();
    parent::submitForm($form, $form_state);
  }

}
